import * as globalaccelerator from '@aws-cdk/aws-globalaccelerator';
import * as route53 from '@aws-cdk/aws-route53';
/**
 * Use a Global Accelerator domain name as an alias record target.
 *
 * @stability stable
 */
export declare class GlobalAcceleratorDomainTarget implements route53.IAliasRecordTarget {
    private readonly acceleratorDomainName;
    /**
     * The hosted zone Id if using an alias record in Route53.
     *
     * This value never changes.
     * Ref: https://docs.aws.amazon.com/general/latest/gr/global_accelerator.html
     *
     * @stability stable
     */
    static readonly GLOBAL_ACCELERATOR_ZONE_ID = "Z2BJ6XQ5FK7U4H";
    /**
     * Create an Alias Target for a Global Accelerator domain name.
     *
     * @stability stable
     */
    constructor(acceleratorDomainName: string);
    /**
     * Return hosted zone ID and DNS name, usable for Route53 alias targets.
     *
     * @stability stable
     */
    bind(_record: route53.IRecordSet): route53.AliasRecordTargetConfig;
}
/**
 * Use a Global Accelerator instance domain name as an alias record target.
 *
 * @stability stable
 */
export declare class GlobalAcceleratorTarget extends GlobalAcceleratorDomainTarget {
    /**
     * Create an Alias Target for a Global Accelerator instance.
     *
     * @stability stable
     */
    constructor(accelerator: globalaccelerator.IAccelerator);
}
